# eric7.PipInterface.PipPackageDetailsDialog

Module implementing a dialog to show details about a package.

### Global Attributes

None

### Classes

PipPackageDetailsDialog | Class implementing a dialog to show details about a package.

### Functions

None

## PipPackageDetailsDialog

Class implementing a dialog to show details about a package.

### Derived from

QDialog, Ui_PipPackageDetailsDialog

### Class Attributes

ButtonInstall
ButtonRemove
ButtonUpgrade

### Class Methods

None

### Methods

PipPackageDetailsDialog | Constructor
__formatSize | Private slot to format the size.
__formatUploadDate | Private method to format the upload date.
__populateDetails | Private method to populate the details tab.
__populateDownloadUrls | Private method to populate the download URLs tab.
__populateRequiresProvides | Private method to populate the requires/provides tab.
__sanitize | Private method to clean-up the given text.
on_buttonBox_clicked | Private slot handling the user pressing an action button.

### Static Methods

None

#### PipPackageDetailsDialog (Constructor)

PipPackageDetailsDialog(detailsData, buttonsMode=0, parent=None)

Constructor

detailsData (dict)
  package details
buttonsMode (int (optional))
  flags telling which convenience buttons to enable (defaults to 0)
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### PipPackageDetailsDialog.__formatSize

__formatSize(size)

Private slot to format the size.

size (int)
  size to be formatted

Return:
  formatted size

Return Type:
  str

#### PipPackageDetailsDialog.__formatUploadDate

__formatUploadDate(datetime)

Private method to format the upload date.

datetime (xmlrpc.DateTime or str)
  upload date and time

Return:
  formatted date string

Return Type:
  str

#### PipPackageDetailsDialog.__populateDetails

__populateDetails(detailsData)

Private method to populate the details tab.

detailsData (dict)
  package details

#### PipPackageDetailsDialog.__populateDownloadUrls

__populateDownloadUrls(downloadsData)

Private method to populate the download URLs tab.

downloadsData (dict)
  downloads information

#### PipPackageDetailsDialog.__populateRequiresProvides

__populateRequiresProvides(detailsData)

Private method to populate the requires/provides tab.

detailsData (dict)
  package details

#### PipPackageDetailsDialog.__sanitize

__sanitize(text, forUrl=False)

Private method to clean-up the given text.

text (str)
  raw text
forUrl (bool)
  flag indicating to sanitize an URL text

Return:
  processed text

Return Type:
  str

#### PipPackageDetailsDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot handling the user pressing an action button.

button (QAbstractButton)
  button activated by the user

Up